<%@ taglib prefix="fmt" uri="http://java.sun.com/jsp/jstl/fmt" %>
<%@ taglib prefix="jcr" uri="http://www.jahia.org/tags/jcr" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib prefix="template" uri="http://www.jahia.org/tags/templateLib" %>
<%@ taglib prefix="uiComponents" uri="http://www.jahia.org/tags/uiComponentsLib" %>
<%@ taglib prefix="query" uri="http://www.jahia.org/tags/queryLib" %>
<%@ taglib prefix="fn" uri="http://java.sun.com/jsp/jstl/functions" %>
<%@ taglib prefix="functions" uri="http://www.jahia.org/tags/functions" %>
<%@ taglib prefix="user" uri="http://www.jahia.org/tags/user" %>

<template:addResources type="javascript" resources="jquery.min.js,jquery-ui.min.js"/>
<template:addResources type="javascript" resources="jquery.fancybox.js,jquery.jeditable.js"/>
<template:addResources type="javascript" resources="jquery.autocomplete.js"/>
<template:addResources type="css" resources="jquery.autocomplete.css"/>
<template:addResources type="css" resources="jquery.fancybox.css"/>

<c:set var="bindedComponent"
       value="${uiComponents:getBindedComponent(currentNode, renderContext, 'j:bindedComponent')}"/>

<jcr:nodeProperty node="${currentNode}" name="rolesList" var="rolesList"/>
<jcr:nodeProperty node="${currentNode}" name="defaultRole" var="defaultRoleProp"/>
<c:set var="providedDefaultRole" value="${not empty defaultRoleProp ? defaultRoleProp.string : ''}"/>
<c:forEach items="${rolesList}" var="role" varStatus="status">
    <c:set var="roleName" value="${role.string}"/>
    <c:set var="roles" value="${roles} ${roleName}"/>
    <c:if test="${status.index>0}">
        <c:set var="rolesJs" value="${rolesJs},"/>
    </c:if>
    <fmt:message key="docspace.label.docspace.role.${roleName}" var="roleLabel"/>
    <c:set var="rolesJs" value="${rolesJs}'${roleName}':'${roleLabel}'"/>
    <c:if test="${status.index==0}"><c:set var="firstRole" value="${roleName}"/></c:if>
    <c:if test="${providedDefaultRole==roleName}"><c:set var="defaultRole" value="${roleName}"/></c:if>
    <c:if test="${status.last}"><c:set var="rolesCount" value="${status.count}"/></c:if>
</c:forEach>
<c:set var="defaultRole" value="${not empty defaultRole ? defaultRole : firstRole}"/>
<c:set var="canManageMembers" value="${jcr:hasPermission(renderContext.mainResource.node,'docspace-member-manage')}"/>
<c:url var="postUrl" value="${url.base}${functions:escapePath(bindedComponent.path)}.addMemberToAcl.do"/>
<ul class="docspace-members" id="rights-${currentNode.identifier}">
    <c:if test="${canManageMembers}">
        <fmt:message key="docspace.label.members.remove.confirm" var="i18nRemoveConfirm"/>
        <template:addResources>
            <script type="text/javascript">
                $(document).ready(function () {
                    <c:if test="${rolesCount > 1}">
                    $(".editRoles").each(function() {
                        var data = {${rolesJs}};
                        data['selected'] = $(this).attr('data-role');
                        $(this).editable(function (value, settings) {
                            $.post("${postUrl}", {"memberKey":$(this).attr('key'), "role":value, "overwrite":true}, function (result) {
                                location.reload();
                            }, "json");
                        }, {
                            type:'select',
                            data:data,
                            submit:'OK'
                        });
                    });
                    </c:if>
                    $(".removeRole").click(function () {
                        if (!confirm("${functions:escapeJavaScript(i18nRemoveConfirm)}")) {
                            return false;
                        }
                        $.post("${postUrl}", {"memberKey":$(this).attr('key'), "role":""}, function (result) {
                            location.reload();
                        }, "json");
                    })
                });
            </script>
        </template:addResources>
    </c:if>

    <c:set var="aclEntries"
           value="${functions:getRolesForNode(renderContext.mainResource.node, false, false, roles, -1, 'displayName')}"/>
    <c:set var="totalSize" value="${fn:length(aclEntries)}"/>
    <template:initPager id="members" totalSize="${totalSize}" pageSize="10"/>

    <jcr:node var="adminSite" path="/sites/wsfaccess"/>

    <c:forEach items="${aclEntries}" var="entry" begin="${moduleMap['begin']}" end="${moduleMap['end']}">
        <li>
            <div class="docspace-member">
                <c:set var="principal" value="${entry['principal']}"/>
                <c:set var="isGroup" value="${entry['principalType'] eq 'group'}"/>
                <c:set var="fullName" value="${fn:escapeXml(user:fullName(principal))}"/>

                    <c:if test="${isGroup}">
                        <img class="docspace-member-img" src="<c:url value='${url.currentModule}/css/img/usergroupbig.png'/>"
                             alt=" "
                             border="0" width="120"
                             height="120"/>
                    </c:if>
                    <c:if test="${!isGroup}">
                        <c:set value="" var="picture"/>
                        <jcr:node var="usernode" path="${principal.localPath}"/> 
                        <jcr:nodeProperty var="picture" node="${usernode}" name="j:picture"/>
                        <c:url var="profileLink" value="${url.baseLive}${principal.localPath}.workspace-${currentNode.session.user.username eq principal.name ? '' : 'public-'}user.html">
                            <c:param name="jsite" value="${adminSite.identifier}"/>
                        </c:url>
                        <a href="${profileLink}">
                        <c:if test="${not empty picture}">
                                <img class="docspace-member-img"
                                     src="${picture.node.thumbnailUrls['avatar_120']}"
                                     alt="${fullName}"
                                     width="120"
                                     height="120"/>
                        </c:if>
                        <c:if test="${empty picture}">
                            <img class="docspace-member-img" src="<c:url value='${url.currentModule}/css/img/userbig.png'/>"
                                 alt="${fullName}"
                                 border="0" width="120"
                                 height="120"/>
                        </c:if>
                        </a>
                    </c:if>
                <div class="caption">

                    <h5>
                    <c:if test="${!isGroup}">
                        <a href="${profileLink}">${fullName}</a>
                    </c:if>
                    <c:if test="${isGroup}">
                        ${fullName}
                    </c:if>
                    </h5>
                    <c:if test="${!isGroup}">
                        <c:set var="userFunction" value="${principal.properties['j:function']}"/>
                        <c:if test="${not empty userFunction}">
                            <p>${fn:escapeXml(userFunction)}</p>
                        </c:if>
                    </c:if>

                    <c:if test="${canManageMembers && (isGroup || currentNode.session.user.username ne principal.name)}">
                        <c:forEach items="${entry['roles']}" var="role">
                            <fmt:message key="docspace.label.docspace.role.${role}.short" var="roleLabel"/>
                            <fmt:message key="docspace.label.docspace.role.${role}" var="roleLabelToolTip"/>
                            <div class="editRoles" key="${isGroup ? 'g' : 'u'}:${principal.name}"
                                  title="${roleLabelToolTip}.&#10;<fmt:message key='label.clickToEdit'/>" data-role="${role}"><span class="inline-editable">${roleLabel}</span></div>
                        </c:forEach>
                    </c:if>
                    <c:if test="${!canManageMembers || (!isGroup && currentNode.session.user.username eq principal.name)}">
                        <c:forEach items="${entry['roles']}" var="role">
                            <fmt:message key="docspace.label.docspace.role.${role}" var="roleLabelToolTip"/>
                            <p title="${roleLabelToolTip}"><fmt:message key="docspace.label.docspace.role.${role}.short"/> </p>
                        </c:forEach>
                    </c:if>

                <c:if test="${canManageMembers}">

                        <c:if test="${isGroup || currentNode.session.user.username ne principal.name}">
                            <button class="removeRole" key="${isGroup ? 'g' : 'u'}:${principal.name}">
                                <span><fmt:message key="label.remove"/></span></button>
                        </c:if>
                    </div>
                </c:if>
            </div>
        </li>
    </c:forEach>
</ul>
<template:displayPagination id="members"/>