<%@ taglib prefix="fmt" uri="http://java.sun.com/jsp/jstl/fmt" %>
<%@ taglib prefix="jcr" uri="http://www.jahia.org/tags/jcr" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib prefix="template" uri="http://www.jahia.org/tags/templateLib" %>
<%@ taglib prefix="uiComponents" uri="http://www.jahia.org/tags/uiComponentsLib" %>
<%@ taglib prefix="query" uri="http://www.jahia.org/tags/queryLib" %>
<%@ taglib prefix="fn" uri="http://java.sun.com/jsp/jstl/functions" %>
<%@ taglib prefix="functions" uri="http://www.jahia.org/tags/functions" %>
<%@ taglib prefix="user" uri="http://www.jahia.org/tags/user" %>

<template:addResources type="javascript" resources="jquery.min.js,jquery-ui.min.js"/>
<template:addResources type="javascript" resources="jquery.fancybox.js,jquery.jeditable.js"/>
<template:addResources type="javascript" resources="jquery.autocomplete.js"/>
<template:addResources type="css" resources="jquery.autocomplete.css"/>
<template:addResources type="css" resources="jquery.fancybox.css"/>

<c:set var="boundComponent"
       value="${uiComponents:getBindedComponent(currentNode, renderContext, 'j:bindedComponent')}"/>

<jcr:nodeProperty node="${currentNode}" name="rolesList" var="rolesList"/>
<jcr:nodeProperty node="${currentNode}" name="defaultRole" var="defaultRoleProp"/>
<c:set var="providedDefaultRole" value="${not empty defaultRoleProp ? defaultRoleProp.string : ''}"/>
<c:set var="rolesJs" value=""/>
<c:forEach items="${rolesList}" var="role" varStatus="status">
    <c:set var="roleName" value="${role.string}"/>
    <c:set var="roles" value="${roles} ${roleName}"/>
    <fmt:message key="docspace.label.docspace.role.${roleName}.short" var="roleLabel"/>
    <c:set var="rolesJs" value="${rolesJs}${not empty rolesJs ? ',' : ''}'${roleName}':'${roleLabel}'"/>
    <c:if test="${status.index==0}"><c:set var="firstRole" value="${roleName}"/></c:if>
    <c:if test="${providedDefaultRole==roleName}"><c:set var="defaultRole" value="${roleName}"/></c:if>
    <c:if test="${status.last}"><c:set var="rolesCount" value="${status.count}"/></c:if>
</c:forEach>
<c:set var="defaultRole" value="${not empty defaultRole ? defaultRole : firstRole}"/>
<c:set var="canManageMembers" value="${jcr:hasPermission(boundComponent, not empty currentResource.moduleParams.membersManagementSourceNode ? 'jcr:modifyAccessControl_default' : 'docspace-member-manage')}"/>
<c:url var="postUrl" value="${url.base}${functions:escapePath(boundComponent.path)}.addMemberToAcl.do"/>

<c:if test="${not param.hideForm && canManageMembers}">
    <div id="addMemberForm">
        <form method="get" id="searchUsersForm" class="searchUsersForm" action="" onsubmit="return false;">
            <fmt:message key='docspace.label.addUsersOrGroups' var="startSearching"/>
            <input type="text" id="searchUsersTerm" value="${startSearching}"
                   onfocus="if(this.value==this.defaultValue)this.value='';"
                   onblur="if(this.value=='')this.value=this.defaultValue;" class="text-input"/>
        </form>
        <br class="clear"/>
    </div>
</c:if>

<div id="rights-${currentNode.identifier}">
    <c:set var="memberDisplayLimit" value="${currentNode.properties.size.long}"/>
    <c:if test="${not param.hideForm && canManageMembers}">
    <fmt:message key="docspace.label.members.add.confirm" var="i18nAdd"/>
    <fmt:message key="message.continue" var="i18nContinue"/>
    <fmt:message key="docspace.label.members.remove.confirm" var="i18nRemoveConfirm"/>
    <template:addResources>
    <script type="text/javascript">
        function getFormattedPrincipal(node) {
      		return '<img id="img_user_'+node['key']+'" src="${url.context}/modules/default/images/' + (node['type'] == 'g' ? 'group-icon' : 'usersmall') + '.png" height="32" width="32"/>&nbsp;' + node['displayName'];
        }

        $(document).ready(function() {
            var callback = function() {};
            <c:url value='${not empty currentResource.moduleParams.membersManagementSourceNode ? url.findUsersAndGroupsInAcl : url.findUsersAndGroups}' var="findUsersGroupsUrl">
                <c:if test="${currentNode.properties.useRolesListForConstrainingUserSearch.boolean}">
                    <c:set var="roles" value=""/>
                    <c:forEach items="${rolesList}" var="roleNode">
                        <c:set var="roleName" value="${roleNode.string}"/>
                        <c:set var="roles" value="${roles} ${roleName}"/>
                    </c:forEach>
                    <c:param name="roles" value="${roles}"/>
                </c:if>
            </c:url>
            $("#searchUsersTerm").autocomplete("${findUsersGroupsUrl}", {
                dataType: "json",
                cacheLength: 1,
                extraParams: {
				<c:if test="${not empty currentResource.moduleParams.membersManagementSourceNode}">
					sourceNode: '${currentResource.moduleParams.membersManagementSourceNode}',
				</c:if>
				<c:if test="${empty currentResource.moduleParams.membersManagementSourceNode}">
					siteId: '${renderContext.site.ID}',
				</c:if>
					emptyResultForBadQuery: true
				},
                parse: function (data) {
                    return $.map(data, function(row) {
                        return { data: row, value: row['key'] }
                    });
                },
                formatItem: function(item) {
                    return getFormattedPrincipal(item);
                }
            }).result(function(event, item, formatted) {
                if (!item || !confirm('${functions:escapeJavaScript(i18nAdd)}:\n\n\t' + item['displayName'] + '\n\n${functions:escapeJavaScript(i18nContinue)}')) {
                    return false;
                }

                $.post("${postUrl}", {"memberKey":item['key'], "role":"${defaultRole}"}, function(result) {
                    <c:choose>
                    <c:when test="${memberDisplayLimit > 0}">
                    $("#${currentNode.identifier}-usersList").load("<c:url value='${url.current}.ajax?mainResource=${functions:escapePath(boundComponent.path)}.html&includeJavascripts=true&hideForm=true'/>",callback);
                    </c:when>
                    <c:otherwise>
                    location.reload();
                    </c:otherwise>
                    </c:choose>
                }, "json");

                return false;
            });

            <c:if test="${memberDisplayLimit > 0}">
            callback = function() {
            <c:if test="${rolesCount > 1}">
            $(".editRoles").each(function() {
                var data = {${rolesJs}};
                data['selected'] = $(this).attr('data-role');
                $(this).editable(function (value, settings) {
                            $.post("${postUrl}", {"memberKey":$(this).attr('key'), "role":value, "overwrite":true}, function(result) {
                                $("#${currentNode.identifier}-usersList").load("<c:url value='${url.current}.ajax?mainResource=${functions:escapePath(boundComponent.path)}.html&includeJavascripts=true&hideForm=true'/>",callback);
                            }, "json");
                        }, {
                            type: 'select',
                            data: data,
                            submit: 'OK'
                        }
                );
            });
            </c:if>
            $(".removeRole").click(function () {
            	if (!confirm("${functions:escapeJavaScript(i18nRemoveConfirm)}")) {
            		return false;
            	}
                $.post("${postUrl}", {"memberKey":$(this).attr('rel'), "role":""}, function (result) {
                    $("#${currentNode.identifier}-usersList").load("<c:url value='${url.current}.ajax?mainResource=${functions:escapePath(boundComponent.path)}.html&includeJavascripts=true&hideForm=true'/>",callback);
                }, "json");
            })
            }
            callback();
            </c:if>
        });
    </script>
    </template:addResources>
    </c:if>

    <div id="${currentNode.identifier}-usersList">
    <c:if test="${memberDisplayLimit > 0}">
    	 <c:if test="${boundComponent.url != renderContext.site.home.url}">
    		<c:set var="aclEntries" value="${functions:getRolesForNode(boundComponent, false, false, roles, memberDisplayLimit, 'latestFirst')}"/>
    			<c:set var="loopcountbegin" value="0"/>	
    			<c:set var="loopcountend" value="${memberDisplayLimit-1}"/>		
    	 </c:if>	
    	 <c:if test="${boundComponent.url == renderContext.site.home.url}">
    		  <c:set var="aclEntries" value="${functions:getRolesForNode(boundComponent, false, false, roles, 1000, 'latestFirst')}"/>
    		  <c:set var="totalSize" value="${fn:length(aclEntries)}"/>
    		  <template:initPager id="docspaceadduser" totalSize="${totalSize}" pageSize="${memberDisplayLimit}"/>
    			<c:set var="loopcountbegin" value="${moduleMap['begin']}"/>	
    			<c:set var="loopcountend" value="${moduleMap['end']}"/>		
    	 </c:if>	

    <jcr:node var="adminSite" path="/sites/wsfaccess"/>
    <c:forEach items="${aclEntries}" var="entry"  begin="${loopcountbegin}" end="${loopcountend}">
        <c:set var="principal" value="${entry['principal']}"/>
        <c:set var="isGroup" value="${entry['principalType'] eq 'group'}"/>
        <c:set var="fullName" value="${fn:escapeXml(user:fullName(principal))}"/>
    <div class="docspaceadduser">
        <div class="user-profile-view">
            <c:if test="${isGroup}">
                    <img class='user-profile-img' src="<c:url value='${url.currentModule}/css/img/group-icon.png'/>"
                         alt=" "
                         border="0" width="60"
                         height="60"/>
            </c:if>
            <c:if test="${!isGroup}">
                <c:set value="" var="picture"/>
                <jcr:node var="usernode" path="${principal.localPath}"/>
                <jcr:nodeProperty var="picture" node="${usernode}" name="j:picture"/>
                <c:url var="profileLink" value="${url.baseLive}${principal.localPath}.workspace-${currentNode.session.user.username eq principal.name ? '' : 'public-'}user.html">
                    <c:param name="jsite" value="${adminSite.identifier}"/>
                </c:url>
                <a href="${profileLink}">
                <c:if test="${not empty picture}">
                        <img class='user-profile-img userProfileImage'
                             src="${picture.node.thumbnailUrls['avatar_120']}"
                             alt="${fullName}"
                             width="60"
                             height="60"/>
                </c:if>
                <c:if test="${empty picture}">
                    <img class='user-profile-img' src="<c:url value='${url.currentModule}/css/img/usersmall.png'/>"
                         alt=" "
                         border="0" width="60"
                         height="60"/>
                </c:if>
                </a>
            </c:if>

          <h5>
          <c:if test="${!isGroup}">
              <a href="${profileLink}">${fullName}</a>
          </c:if>
          <c:if test="${isGroup}">
            ${fullName}
          </c:if>
          </h5>
          <c:if test="${!isGroup and not empty principal.properties['j:function']}">
          <p>${fn:escapeXml(principal.properties['j:function'])}</p>
          </c:if>
            <c:if test="${canManageMembers && (isGroup || currentNode.session.user.username ne principal.name)}">
                <c:set var="principalKey" value="${isGroup ? 'g' : 'u'}:${principal.name}"/>

                <c:forEach items="${entry['roles']}" var="role">
                    <fmt:message key="docspace.label.docspace.role.${role}.short" var="roleLabel"/>
                    <p class="editRoles" key="${principalKey}" title="<fmt:message key='label.clickToEdit'/>" data-role="${role}"><span class="inline-editable">${roleLabel}</span></p>
                </c:forEach>
                <p><a href="#remove" class="removeRole" rel="${principalKey}" title="<fmt:message key='label.remove'/>"></a></p>
            </c:if>
            <c:if test="${!canManageMembers || (!isGroup && currentNode.session.user.username eq principal.name)}">
                <c:forEach items="${entry['roles']}" var="role">
                    <p><fmt:message key="docspace.label.docspace.role.${role}.short" /></p>
                </c:forEach>
            </c:if>
          <div class="clear"></div>

        </div>
    </div>
    </c:forEach>
    
     <c:if test="${boundComponent.url == renderContext.site.home.url}">
    		<template:displayPagination id="docspaceadduser"/>
     </c:if>	
    	
     <c:if test="${boundComponent.url != renderContext.site.home.url}">
      <c:if test="${fn:length(aclEntries) >= memberDisplayLimit}">
        <c:url var="allMembersUrl" value="${boundComponent.path}.workspace-members.html" context="${url.context}${url.base}"/>
        <a class="floatright" href="${allMembersUrl}"><fmt:message key="docspace.label.members.viewall"/></a>
      </c:if>
     </c:if>
    </c:if>	
        </div>

</div>