<%@ taglib prefix="fmt" uri="http://java.sun.com/jsp/jstl/fmt" %>
<%@ taglib prefix="jcr" uri="http://www.jahia.org/tags/jcr" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib prefix="template" uri="http://www.jahia.org/tags/templateLib" %>
<%@ taglib prefix="uiComponents" uri="http://www.jahia.org/tags/uiComponentsLib" %>
<%@ taglib prefix="query" uri="http://www.jahia.org/tags/queryLib" %>
<%@ taglib prefix="fn" uri="http://java.sun.com/jsp/jstl/functions" %>
<%@ taglib prefix="functions" uri="http://www.jahia.org/tags/functions" %>
<%@ taglib prefix="user" uri="http://www.jahia.org/tags/user" %>

<template:addResources type="javascript" resources="jquery.min.js,jquery-ui.min.js"/>
<template:addResources type="javascript" resources="jquery.fancybox.js,jquery.jeditable.js"/>
<template:addResources type="javascript" resources="jquery.autocomplete.js"/>
<template:addResources type="css" resources="jquery.autocomplete.css"/>
<template:addResources type="css" resources="jquery.fancybox.css"/>

<c:set var="bindedComponent"
       value="${uiComponents:getBindedComponent(currentNode, renderContext, 'j:bindedComponent')}"/>

<jcr:nodeProperty node="${currentNode}" name="rolesList" var="rolesList"/>
<jcr:nodeProperty node="${currentNode}" name="defaultRole" var="defaultRoleProp"/>
<c:set var="providedDefaultRole" value="${not empty defaultRoleProp ? defaultRoleProp.string : ''}"/>
<c:forEach items="${rolesList}" var="role" varStatus="status">
    <c:set var="roleName" value="${role.string}"/>
    <c:set var="roles" value="${roles} ${roleName}"/>
    <c:if test="${status.index>0}">
        <c:set var="rolesJs" value="${rolesJs},"/>
    </c:if>
    <fmt:message key="docspace.label.docspace.role.${roleName}" var="roleLabel"/>
    <c:set var="rolesJs" value="${rolesJs}'${roleName}':'${roleLabel}'"/>
    <c:if test="${status.index==0}"><c:set var="firstRole" value="${roleName}"/></c:if>
    <c:if test="${providedDefaultRole==roleName}"><c:set var="defaultRole" value="${roleName}"/></c:if>
</c:forEach>
<c:set var="defaultRole" value="${not empty defaultRole ? defaultRole : firstRole}"/>
<c:set var="canManageMembers" value="${jcr:hasPermission(renderContext.mainResource.node,'docspace-member-manage')}"/>
<c:url var="postUrl" value="${url.base}${bindedComponent.path}.addMemberToAcl.do"/>
<div id="rights-${currentNode.identifier}">

    <fmt:message key="docspace.label.members.remove.confirm" var="i18nRemoveConfirm"/>
    <template:addResources>
        <script type="text/javascript">
            $(document).ready(function () {
                <c:if test="${canManageMembers}">
                $(".editRolesFull").editable(function (value, settings) {
                    $.post("${postUrl}", {"memberKey":$(this).attr('key'), "role":value, "overwrite":true},
                            function (result) {
                                location.reload();
                            }, "json");
                }, {
                    type:'select',
                    data:"{${rolesJs}}",
                    submit:'OK'
                });

                $(".removeRole").click(function () {
                    if (!confirm("${functions:escapeJavaScript(i18nRemoveConfirm)}")) {
                        return false;
                    }
                    $.post("${postUrl}", {"memberKey":$(this).attr('key'), "role":""}, function (result) {
                        location.reload();
                    }, "json");
                });
                </c:if>
                function getText(node) {
                    return node["jcr:title"];
                }

                function format(result) {
                    return getText(result["node"]);
                }

                $(".skillSelection").autocomplete("<c:url value='${url.find}'/>", {
                    dataType:"json",
                    dataType: "json",
                    cacheLength: 1,
                    parse: function parse(data) {
                        var arr =  $.map(data, function(row) {
                            return {
                                data: row,
                                value: getText(row["node"]),
                                result: getText(row["node"])
                            }
                        });
                        var sorted_arr = arr.sort(function(a,b) {
                            var nameA=a["value"], nameB=b["value"].toLowerCase();
                            if (nameA < nameB) //sort string ascending
                                return -1;
                            if (nameA > nameB)
                                return 1;
                            return 0;
                        });
                        var results = [];
                        for (var i = 0; i < arr.length; i++) {
                            if (i == 0 || sorted_arr[i - 1]["value"] != sorted_arr[i]["value"]) {
                                results.push(sorted_arr[i]);
                            }
                        }
                        return results;
                    },
                    formatItem: function(item) {
                        return format(item);
                    },
                    extraParams: {
                        query : "select * from [docnt:skill] as skill where lower(skill.[jcr:title]) like '{$q}%' or lower(skill.[jcr:title]) like '% {$q}%'",
                        escapeColon : "false",
                        propertyMatchRegexp : "{$q}.*",
                        removeDuplicatePropValues : "false"
                    }
                });
            });
        </script>
    </template:addResources>

    <div>
        <form class="userManagementSkillsForm" action="" method="get">
            <input type="hidden" name="displayTab" value="skill-search"/>
            <input type="hidden" name="d" value="true"/>
            <fieldset id="searchMembersFS">
                <p>
                <label for="searchmembersskills"><fmt:message key="docnt_skill"/></label>
                <input type="text" value="${fn:escapeXml(param.ski)}" name="ski" maxlength="32" size="16" class="field skillSelection"
                       id="searchmembersskills"/>
                 </p>
                <p>
                <label for="searchmemberslevels"><fmt:message key="docnt_skill.level"/></label>
                <select class="field" name="lev" id="searchmemberslevels">
                    <jcr:propertyInitializers var="levels" name="level" nodeType="docnt:skill"/>
                    <option value="any"><fmt:message key="docspace.label.user.dir.any"/></option>
                    <c:forEach items="${levels}" var="level">
                        <option value="${level.value.string}"<c:if test="${not empty param.lev and param.lev eq level.value.string}">selected="selected"</c:if> >${level.displayName}</option>
                    </c:forEach>
                </select>
                </p>
            </fieldset>
            <input class="button" type="submit" value="<fmt:message key='search.submit'/>"/>
        </form>
    </div>


    <c:if test="${not empty param.d}">
        <c:if test="${not empty param.ski}">
            <c:set var="statement" value="select * from [docnt:skill] as skill where (localname(skill) = '${fn:toLowerCase(param.ski)}' or lower(skill.[jcr:title]) like '${fn:toLowerCase(param.ski)}')"/>
            <c:if test="${not empty param.lev and param.lev != 'any'}">
                <c:set var="statement" value="${statement} and skill.['level']='${param.lev}'"/>
            </c:if>
            <jcr:jqom var="skills" statement="${statement}"/>
        </c:if>
        <c:set var="totalSize" value="${fn:length(skills.nodes)}"/>

        <template:initPager id="members" totalSize="${totalSize}" pageSize="25"/>
        
        <ul class="docspace-users">
            <c:set var="isEmptyResult" value="true"/>
            <c:forEach items="${skills.nodes}" var="skill" begin="${moduleMap['begin']}" end="${moduleMap['end']}">
                <c:set var="isEmptyResult" value="false"/>
                <c:set var="userNode" value="${jcr:getParentOfType(skill, 'jnt:user')}"/>
                <c:set var="entry" value="${user:lookupUser(userNode.name)}"/>
                <%@ include file="userEntry.jspf" %>
            </c:forEach>
            <c:if test="${isEmptyResult}">
                <fmt:message key="docspace.label.empty.search.user"/>
            </c:if>
        </ul>

        <template:displayPagination id="members"/>
    </c:if>
</div>